@@ -171,7 +171,7 @@ class BaseMeasureCompiler(object):
         - totals by category
         - totals by type
 
-    Totals are used in a second time to compute "total" measures 
+    Totals are used in a second time to compute "total" measures
     (not related to account numbers)
     """
     measure_type_class = None
@@ -611,6 +611,7 @@ enDI
         self.session.flush()
         return self.processed_grids
 
+
 def get_measure_compilers(data_type, grid_type=None):
     """
     Retrieve the measure compilers to be used with this given type of datas
@@ -669,6 +670,7 @@ def send_error(request, mail_addresses, type_label, message):
         except:
             logger.exception("Error sending email")
 
+
 def _collect_operations(upload_id, data_type, upload_date):
     """
     Return the operations needed.
@@ -800,6 +802,7 @@ def _collect_operations(upload_id, data_type, upload_date):
 
     return current_exercice_operations
 
+
 @celery_app.task(bind=True)
 def compile_measures_task(self, upload_id, grid_type=None):
     """
@@ -894,7 +897,7 @@ def scheduled_compile_measure_task(self, force=False):
         AccountingOperationUpload.filetype ==
         AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING
     ).filter(
-        AccountingOperationUpload.created_at >= yesterday
+        AccountingOperationUpload.updated_at >= yesterday
     ).order_by(
         desc(AccountingOperationUpload.id)
     ).first()
@@ -914,9 +917,20 @@ since yesterday"
             IncomeStatementMeasureCompiler,
         ]
         for measure_compiler_factory in measure_compiler_factories:
+            operations = None
+            if measure_compiler_factory == TreasuryMeasureCompiler:
+                operations = _collect_operations(
+                    upload.id,
+                    upload_object.filetype,
+                    upload_object.created_at.date()
+                )
+            else:
+                operations = AccountingOperation.query().filter_by(
+                    upload_id=upload.id
+                ).all()
             try:
                 measure_compiler = measure_compiler_factory(
-                    upload_object, upload_object.operations
+                    upload_object, operations
                 )
                 measure_compiler.process_datas()
             except Exception as err:
